use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
Betts
Carrubba
David
Diab
Edward
Gian
Golden
Graham
Inkster
Iterator
Jerius
Knop
PIR
Path
Piero
Rezic
Ricardo
Rule
Signes
Slaven
Steinbrunner
Toby
dagolden
djerius
dsteinbrunner
edward
gpiero
haarg
lib
postorder
rjbs
slaven
subclasses
timestamps
tobyink
tuples
